pub enum ByteErrorKind {
Truncated,
LengthOverflow,
BudgetExceeded,
OverlongModifiedUtf8,
IllegalZero,
InvalidModifiedUtf8,
MalformedSurrogate,
}Expand description
A precise byte-lane failure category.
Variants
Truncated
The input ended before the requested value was complete.
LengthOverflow
Offset or length arithmetic overflowed.
BudgetExceeded
A declared or produced value exceeded its allocation budget.
OverlongModifiedUtf8
Modified UTF-8 used a longer representation than necessary.
IllegalZero
Modified UTF-8 contained a literal zero byte.
InvalidModifiedUtf8
Modified UTF-8 contained an invalid byte sequence.
MalformedSurrogate
Modified UTF-8 contained an unpaired UTF-16 surrogate.