StackMapFrame

Enum StackMapFrame 

pub enum StackMapFrame {
    Same {
        frame_type: u8,
    },
    SameLocalsOneStack {
        frame_type: u8,
        stack: VerificationType,
    },
    SameLocalsOneStackExtended {
        offset_delta: u16,
        stack: VerificationType,
    },
    Chop {
        frame_type: u8,
        offset_delta: u16,
    },
    SameExtended {
        offset_delta: u16,
    },
    Append {
        frame_type: u8,
        offset_delta: u16,
        locals: Vec<VerificationType>,
    },
    Full {
        offset_delta: u16,
        locals: Vec<VerificationType>,
        stack: Vec<VerificationType>,
    },
}
One compressed stack-map frame, retained without expansion.

Variants



Same

Tags 0 through 63.

Fields

frame_type: u8

Encoded frame tag, which is also the offset delta.



SameLocalsOneStack

Tags 64 through 127.

Fields

frame_type: u8

Encoded frame tag.

stack: VerificationType

Sole stack entry.



SameLocalsOneStackExtended

Tag 247.

Fields

offset_delta: u16

Explicit offset delta.

stack: VerificationType

Sole stack entry.



Chop

Tags 248 through 250.

Fields

frame_type: u8

Encoded frame tag, retaining the exact number of omitted locals.

offset_delta: u16

Explicit offset delta.



SameExtended

Tag 251.

Fields

offset_delta: u16

Explicit offset delta.



Append

Tags 252 through 254.

Fields

frame_type: u8

Encoded frame tag, retaining the exact number of appended locals.

offset_delta: u16

Explicit offset delta.

locals: Vec<VerificationType>

Appended locals in encoded order.



Full

Tag 255.

Fields

offset_delta: u16

Explicit offset delta.

locals: Vec<VerificationType>

Complete locals in encoded order.

stack: Vec<VerificationType>

Complete stack in encoded order.