pub fn decode_instructions(
code: &[u8],
major_version: u16,
pool: &ConstantPool,
) -> Result<DecodedCode, InstructionError>Expand description
Decode JVM instructions using generated metadata plus the three irregular layouts.
pub fn decode_instructions(
code: &[u8],
major_version: u16,
pool: &ConstantPool,
) -> Result<DecodedCode, InstructionError>Decode JVM instructions using generated metadata plus the three irregular layouts.